[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- fedex: The python-fedex module is a light wrapper around Fedex's Web Services SOAP API.
  - fedex.base_service: The base_service module contains classes that form the low level foundations of the Web Service API.
  - fedex.config: The config module contains the FedexConfig class, which is passed to the Fedex API calls.
  - fedex.printers: Optional classes used for the convenient printing of FedEx labels from FedexProcessShipmentRequest objects.
    - fedex.printers.unix: This module provides a label printing wrapper class for Unix-based installations.
  - fedex.services: This module contains the wrappers around Fedex Web Service requests which you will want to instantiate and use with a FedexConfig object supplying your static details.
    - fedex.services.address_validation_service: This package contains the shipping methods defined by Fedex's AddressValidationService WSDL file.
    - fedex.services.package_movement: This package contains classes to check service availability, route, and postal codes.
    - fedex.services.rate_service: This package contains classes to request pre-ship rating information and to determine estimated or courtesy billing quotes.
    - fedex.services.ship_service: This package contains the shipping methods defined by Fedex's ShipService WSDL file.
    - fedex.services.track_service: This package contains the shipment tracking methods defined by Fedex's TrackService WSDL file.